@@ -431,9 +431,11 @@ bool GlobalShortcutsRegistry::keyPressed(int keyQt)
     case Qt::Key_Super_R:
     case Qt::Key_Meta:
         m_state = PressingModifierOnly;
+        m_currentModifiers = Utils::keyToModifier(key) | modifiers;
         return false;
     default:
         m_state = Normal;
+        m_currentModifiers = modifiers;
         return processKey(keyQt);
     }
 }
@@ -532,9 +534,13 @@ bool GlobalShortcutsRegistry::keyReleased(int keyQt)
     case Qt::Key_Control:
     case Qt::Key_Alt: {
         if (m_state == PressingModifierOnly) {
-            handled = processKey(modifiers | Utils::keyToModifier(key));
+            m_state = ReleasingModifierOnly;
+            handled = processKey(m_currentModifiers);
+        }
+        m_currentModifiers = modifiers & ~Utils::keyToModifier(key);
+        if (m_state == ReleasingModifierOnly && !m_currentModifiers) {
+            m_state = Normal;
         }
-        m_state = Normal;
         break;
     }
     default:
